@@ -1,5 +1,5 @@
 import re
-from typing import Optional
+from typing import Dict, Optional
 from pathlib import Path
 
 import httpx
@@ -29,14 +29,14 @@ def parse_msg(msg: str) -> str:
 
 async def get_img(url: str) -> Optional[bytes]:
     headers = {
-        "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
-        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/95.0.4638.69 Safari/537.36 Edg/95.0.1020.53",
+        "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",  # noqa
+        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/95.0.4638.69 Safari/537.36 Edg/95.0.1020.53",  # noqa
     }
     try:
         async with httpx.AsyncClient() as client:
             resp = await client.get(url, headers=headers)
             return resp.content
-    except:
+    except httpx.TimeoutException:
         logger.warning(f"图片下载失败：{url}")
         return None
 
@@ -141,3 +141,14 @@ def include_msg(msg1: Message, msg2: Message) -> bool:
         elif not compare_msgseg(m1, m2):
             return False
     return True
+
+
+def to_json(msg: Message, name: str, bot_id: str) -> Dict:
+    return {
+        "type": "node",
+        "data": {
+            "name": name,
+            "uin": bot_id,
+            "content": msg,
+        },
+    }
